==> haskell-cassava-megaparsec-2.1.1-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cassava-megaparsec
version:              2.1.1
visibility:           public
id:                   cassava-megaparsec-2.1.1-7UvmV3jDxe8CPpmzo1Z3SM
key:                  cassava-megaparsec-2.1.1-7UvmV3jDxe8CPpmzo1Z3SM
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  ccbc005c0fa8bd6635af413d3829dc5a
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava-megaparsec
hs-libraries:         HScassava-megaparsec-2.1.1-7UvmV3jDxe8CPpmzo1Z3SM
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cassava-0.5.4.0-FnvZEQ8p9Ma3zlxKhBsuTo
    megaparsec-9.7.0-41F5K5g8jfX9jzQ5gGX83m
    unordered-containers-0.2.20-3371VA61Be1CojVrkG24uM
    vector-0.13.2.0-EWs7nDhBFQF5RfgCWU6KmC

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-megaparsec-2.1.1-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cassava-megaparsec
version:              2.1.1
visibility:           public
id:                   cassava-megaparsec-2.1.1-3qYNsKeELNm3G6Rq4PZE9A
key:                  cassava-megaparsec-2.1.1-3qYNsKeELNm3G6Rq4PZE9A
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  f615f3eebe9189113956e2fa4321b7d1
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava-megaparsec
hs-libraries:         HScassava-megaparsec-2.1.1-3qYNsKeELNm3G6Rq4PZE9A
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cassava-0.5.4.0-Bj1YOEnsPcG2yBOoA2RQ6M
    megaparsec-9.7.0-9KX7uZoGWhIHAGHTH7OWSU
    unordered-containers-0.2.20-3NcLl7S6t7kAuh7l4Ieeoo
    vector-0.13.2.0-CQ8QMV1t4PN5YFZtNXivGS

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
